@@ -64,7 +64,7 @@ DQuickWindowAttachedPrivate::DQuickWindowAttachedPrivate(QWindow *window, DQuick
     : DObjectPrivate(qq)
     , window(window)
     , wmWindowTypes(DWindowManagerHelper::UnknowWindowType)
-    , appLoaderItem(new DQuickAppLoaderItem())
+    , appLoaderItem(nullptr)
 {
 }
 
@@ -108,6 +108,24 @@ inline static void updateValue(QPoint &value, Func call)
     }
 }
 
+template<class Func>
+inline static void updateValue(DTK_GUI_NAMESPACE::DPlatformHandle::EffectScenes &value, Func call)
+{
+    if (value != DTK_GUI_NAMESPACE::DPlatformHandle::EffectScene(0)) {
+        call(value);
+        value = DTK_GUI_NAMESPACE::DPlatformHandle::EffectScene(0);
+    }
+}
+
+template<class Func>
+inline static void updateValue(DTK_GUI_NAMESPACE::DPlatformHandle::EffectTypes &value, Func call)
+{
+    if (value != DTK_GUI_NAMESPACE::DPlatformHandle::EffectType(0)) {
+        call(value);
+        value = DTK_GUI_NAMESPACE::DPlatformHandle::EffectType(0);
+    }
+}
+
 bool DQuickWindowAttachedPrivate::ensurePlatformHandle()
 {
     if (handle)
@@ -133,6 +151,8 @@ bool DQuickWindowAttachedPrivate::ensurePlatformHandle()
     updateValue(explicitEnableSystemResize, std::bind(&DPlatformHandle::setEnableSystemResize, handle, std::placeholders::_1));
     updateValue(explicitEnableSystemMove, std::bind(&DPlatformHandle::setEnableSystemMove, handle, std::placeholders::_1));
     updateValue(explicitEnableBlurWindow, std::bind(&DPlatformHandle::setEnableBlurWindow, handle, std::placeholders::_1));
+    updateValue(explicitEffectScene, std::bind(&DPlatformHandle::setWindowEffect, handle, std::placeholders::_1));
+    updateValue(explicitEffectType, std::bind(&DPlatformHandle::setWindowStartUpEffect, handle, std::placeholders::_1));
 
     QObject::connect(handle, &DPlatformHandle::borderColorChanged, q, &DQuickWindowAttached::borderColorChanged);
     QObject::connect(handle, &DPlatformHandle::borderWidthChanged, q, &DQuickWindowAttached::borderWidthChanged);
@@ -145,6 +165,8 @@ bool DQuickWindowAttachedPrivate::ensurePlatformHandle()
     QObject::connect(handle, &DPlatformHandle::enableSystemResizeChanged, q, &DQuickWindowAttached::enableSystemResizeChanged);
     QObject::connect(handle, &DPlatformHandle::enableBlurWindowChanged, q, &DQuickWindowAttached::enableBlurWindowChanged);
     QObject::connect(handle, SIGNAL(enableBlurWindowChanged()), q, SLOT(_q_updateBlurAreaForWindow()));
+    QObject::connect(handle, &DPlatformHandle::windowEffectChanged, q, &DQuickWindowAttached::windowEffectChanged);
+    QObject::connect(handle, &DPlatformHandle::windowStartUpEffectChanged, q, &DQuickWindowAttached::windowStartUpEffectChanged);
     Q_EMIT q->enabledChanged();
     return true;
 }
@@ -215,9 +237,11 @@ void DQuickWindowAttachedPrivate::_q_updateBlurAreaForWindow()
         }
     }
 
+    bool blurSuc = false;
+
     if (blurPathList.isEmpty()) {
-        q->setWindowBlurAreaByWM(blurPathList);
-        q->setWindowBlurAreaByWM(blurAreaList);
+        blurSuc = q->setWindowBlurAreaByWM(blurPathList);
+        blurSuc = q->setWindowBlurAreaByWM(blurAreaList);
     } else {
         // convert to QPainterPath
         for (const DPlatformHandle::WMBlurArea &area : qAsConst(blurAreaList)) {
@@ -226,8 +250,12 @@ void DQuickWindowAttachedPrivate::_q_updateBlurAreaForWindow()
             blurPathList << path;
         }
 
-        q->setWindowBlurAreaByWM(QVector<DPlatformHandle::WMBlurArea>{});
-        q->setWindowBlurAreaByWM(blurPathList);
+        blurSuc = q->setWindowBlurAreaByWM(QVector<DPlatformHandle::WMBlurArea>{});
+        blurSuc = q->setWindowBlurAreaByWM(blurPathList);
+    }
+
+    if (!blurSuc) {
+        q->setEnableBlurWindow(true);
     }
 }
 
@@ -314,7 +342,8 @@ QQuickWindow *DQuickWindowAttached::window() const
 bool DQuickWindowAttached::isEnabled() const
 {
     D_DC(DQuickWindowAttached);
-    return d->handle && DPlatformHandle::isEnabledDXcb(window());
+    return d->handle && (DPlatformHandle::isEnabledDXcb(window())
+        || DGuiApplicationHelper::testAttribute(DGuiApplicationHelper::IsTreelandPlatform));
 }
 
 /*!
@@ -459,6 +488,10 @@ QQmlComponent *DQuickWindowAttached::loadingOverlay() const
 DQuickAppLoaderItem *DQuickWindowAttached::appLoader() const
 {
     D_DC(DQuickWindowAttached);
+    if (!d->appLoaderItem) {
+        const_cast<DQuickWindowAttachedPrivate *>(d)->appLoaderItem =
+                new DQuickAppLoaderItem(window()->contentItem());
+    }
     return d->appLoaderItem;
 }
 
@@ -471,7 +504,9 @@ void DQuickWindowAttached::setAppLoader(DQuickAppLoaderItem *item)
     // AppLoaderItem 会在窗口加载完毕后进行创建，因此
     // 在窗口创建初期，AppLoaderItem 需要指定一个默认
     // 值，防止 Qt 在运行时出现警告和报错
-    d->appLoaderItem->deleteLater();
+    if (d->appLoaderItem) {
+        d->appLoaderItem->deleteLater();
+    }
     d->appLoaderItem = item;
     Q_EMIT appLoaderChanged();
 }
@@ -486,6 +521,28 @@ void DQuickWindowAttached::setLoadingOverlay(QQmlComponent *component)
     Q_EMIT loadingOverlayChanged();
 }
 
+void DQuickWindowAttached::setWindowEffect(DTK_GUI_NAMESPACE::DPlatformHandle::EffectScenes effect)
+{
+    D_D(DQuickWindowAttached);
+
+    d->ensurePlatformHandle();
+    if (d->handle)
+        d->handle->setWindowEffect(effect);
+    else
+        d->explicitEffectScene = effect;
+}
+
+void DQuickWindowAttached::setWindowStartUpEffect(DTK_GUI_NAMESPACE::DPlatformHandle::EffectTypes type)
+{
+    D_D(DQuickWindowAttached);
+
+    d->ensurePlatformHandle();
+    if (d->handle)
+        d->handle->setWindowStartUpEffect(type);
+    else
+        d->explicitEffectType = type;
+}
+
 /*!
  * \~chinese \property DQuickWindowAttached::translucentBackground
  * \~chinese \brief 如果此属性值为 true，则在更新窗口绘制内容之前会先清空要更新区域内的图像，否则不清空。
@@ -620,6 +677,29 @@ void DQuickWindowAttached::resetThemeType()
 }
 #endif
 
+
+DTK_GUI_NAMESPACE::DPlatformHandle::EffectScene DQuickWindowAttached::windowEffect() const
+{
+    D_DC(DQuickWindowAttached);
+
+    if (!d->handle) {
+        return DTK_GUI_NAMESPACE::DPlatformHandle::EffectScene(0);
+    }
+
+    return d->handle->windowEffect();
+}
+
+DTK_GUI_NAMESPACE::DPlatformHandle::EffectType DQuickWindowAttached::windowStartUpEffect() const
+{
+    D_DC(DQuickWindowAttached);
+
+    if (!d->handle) {
+        return DTK_GUI_NAMESPACE::DPlatformHandle::EffectType(0);
+    }
+
+    return d->handle->windowStartUpEffect();
+}
+
 /*!
  * \~chinese \brief DQuickWindowAttached::setEnabled　设置当前的窗口为 DTK 风格。
  * \~chinese \note 只能把默认风格设置为 DTK 风格，不能把 DTK 设置为默认风格。
